--- src/fl_cursor.cxx	2014-10-29 21:53:52.000000000 +0600
+++ src/fl_cursor.cxx	2015-02-17 13:12:44.109910748 +0600
@@ -29,6 +29,12 @@
 #include <FL/x.H>
 #include <FL/fl_draw.H>
 
+#include <config.h>
+#if HAVE_XCURSOR
+#include <FL/x.H>
+#include <X11/Xcursor/Xcursor.h>
+#endif
+
 #include "fl_cursor_wait.xpm"
 #include "fl_cursor_help.xpm"
 #include "fl_cursor_nwse.xpm"
@@ -64,6 +70,11 @@
 static void fallback_cursor(Fl_Window *w, Fl_Cursor c) {
   const char **xpm;
   int hotx, hoty;
+  
+  #if HAVE_XCURSOR
+  static Cursor nwse = None;
+  static Cursor nesw = None;
+  #endif
 
   // The standard arrow is our final fallback, so something is broken
   // if we get called back here with that as an argument.
@@ -83,11 +94,21 @@
     break;
   case FL_CURSOR_NWSE:
     xpm = (const char**)fl_cursor_nwse_xpm;
+    #if HAVE_XCURSOR
+    if (!nwse) nwse = XcursorLibraryLoadCursor (fl_display, "size_fdiag"); // Oxygen themes
+    if (!nwse) nwse = XcursorLibraryLoadCursor (fl_display, "fd_double_arrow"); // Crystal themes
+    if (!nwse) nwse = XcursorLibraryLoadCursor (fl_display, "nwse-resize"); // ? theme
+    #endif
     hotx = 7;
     hoty = 7;
     break;
   case FL_CURSOR_NESW:
     xpm = (const char**)fl_cursor_nesw_xpm;
+    #if HAVE_XCURSOR
+    if (!nesw) nesw = XcursorLibraryLoadCursor (fl_display, "size_bdiag"); // Oxygen themes
+    if (!nesw) nesw = XcursorLibraryLoadCursor (fl_display, "bd_double_arrow"); // Crystal themes
+    if (!nesw) nesw = XcursorLibraryLoadCursor (fl_display, "nesw-resize"); // ? theme
+    #endif
     hotx = 7;
     hoty = 7;
     break;
@@ -101,10 +122,19 @@
     return;
   }
 
-  Fl_Pixmap pxm(xpm);
-  Fl_RGB_Image image(&pxm);
-
-  w->cursor(&image, hotx, hoty);
+  #if HAVE_XCURSOR
+  if (c == FL_CURSOR_NWSE && nwse) {
+   XDefineCursor(fl_display, fl_xid(w), nwse);
+  } else if (c == FL_CURSOR_NESW && nesw) {
+   XDefineCursor(fl_display, fl_xid(w), nesw);
+  } else
+  #endif
+  {
+   Fl_Pixmap pxm(xpm);
+   Fl_RGB_Image image(&pxm);
+   w->cursor(&image, hotx, hoty);
+  }
+  
 }
 
 
